==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_StoryArchive.pm <==
package WebGUI::i18n::Spanish::Asset_StoryArchive;
use utf8;
our $I18N = {
  'add a story' => {
    'lastUpdated' => '1253707884',
    'message' => 'Agregar Noticia'
  },
  'addStoryUrl' => {
    'lastUpdated' => '1253707899',
    'message' => 'El URL para agregar Noticia.'
  },
  'approval workflow' => {
    'lastUpdated' => '1253707911',
    'message' => 'Flujo de Trabajo para Aprobar Noticia'
  },
  'approval workflow help' => {
    'lastUpdated' => '1253707971',
    'message' => 'Seleccione el Flujo de Trabajo que será activado cuando se recibe una Noticia.'
  },
  'approvalWorkflowId' => {
    'lastUpdated' => '1253707992',
    'message' => 'El ID del Flujo de Trabajo a ejecutar cada vez que se envía una Noticia.'
  },
  'archive after' => {
    'lastUpdated' => '1253708028',
    'message' => 'Archivar Noticias después de'
  },
  'archive after help' => {
    'lastUpdated' => '1253708090',
    'message' => 'Una vez transcurrida esta cantidad de tiempo, las Noticias serán archivadas y no aparecerán en la lista de Noticias ni en las Fuentes RSS. Ingrese 0 para deshabilitar el archivado de Noticias.'
  },
  'archiveAfter' => {
    'lastUpdated' => '1253708144',
    'message' => 'Cantidad de tiempo en segundos después de la cual las Noticias deben ser archivadas.'
  },
  'asset title' => {
    'lastUpdated' => '1253708156',
    'message' => 'El Título de este Activo.'
  },
  'asset url' => {
    'lastUpdated' => '1253708183',
    'message' => 'El URL de este Activo.'
  },
  'assetName' => {
    'lastUpdated' => '1253708233',
    'message' => 'Archivo de Noticias'
  },
  'asset_loop' => {
    'lastUpdated' => '1253708276',
    'message' => 'Un ciclo que itera sobre los 50 primeros Activos que coinciden con la palabra clave.'
  },
  'atomUrl' => {
    'lastUpdated' => '1253708336',
    'message' => 'El URL para la Fuente Atom de este Archivo de Noticias.'
  },
  'canPostStories' => {
    'lastUpdated' => '1253708417',
    'message' => 'Un condicional que indica si el usuario puede publicar Noticias.'
  },
  'creationDate' => {
    'lastUpdated' => '1253708438',
    'message' => 'La fecha en que la Noticia fue creada o enviada al Archivo de Noticias, como una época Unix.'
  },
  'date_loop' => {
    'lastUpdated' => '1253708474',
    'message' => 'Un ciclo que contiene Noticias en el orden de fecha de envío, con ciclos anidados para cada día.'
  },
  'deleteIcon' => {
    'lastUpdated' => '1253708510',
    'message' => 'El ícono para eliminar esta Noticia. Si el usuario no tiene privilegios para eliminar la Noticia o su nivel de interfaz de usuario es muy bajo, la variable estará vacía.'
  },
  'edit story template' => {
    'lastUpdated' => '1253709395',
    'message' => 'Plantilla para Editar Noticia'
  },
  'edit story template help' => {
    'lastUpdated' => '1253709409',
    'message' => 'Seleccione la Plantilla empleada para agregar o editar Noticias.'
  },
  'editIcon' => {
    'lastUpdated' => '1253709441',
    'message' => 'El ícono para editar esta Noticia. Si el usuario no tiene privilegios para editar la Noticia, o su nivel de Interfaz de Usuario es muy bajo, la variable estará vacía.'
  },
  'editStoryTemplateId' => {
    'lastUpdated' => '1253709455',
    'message' => 'El ID de la Plantilla empleada para agregar o editar Noticias.'
  },
  'epochDate' => {
    'lastUpdated' => '1253709486',
    'message' => 'La época de una Noticia es el comienzo del día para el día en que se agregaron Noticias al Archivo de Noticias.'
  },
  'group to post' => {
    'lastUpdated' => '1253709495',
    'message' => 'Grupo que puede Publicar'
  },
  'group to post help' => {
    'lastUpdated' => '1253709509',
    'message' => 'Seleccione el Grupo de usuarios que puede agregar Noticias al Archivo de Noticias.'
  },
  'groupToPost' => {
    'lastUpdated' => '1253709528',
    'message' => 'El GUID del Grupo que puede agregar historias al Archivo de Noticias.'
  },
  'keyword' => {
    'lastUpdated' => '1253709540',
    'message' => 'La palabra clave para esta lista de Activos.'
  },
  'keyword list template' => {
    'lastUpdated' => '1253709560',
    'message' => 'Archivo de Noticias, Plantilla para Lista de Palabras Clave'
  },
  'keyword list template help' => {
    'lastUpdated' => '1253709608',
    'message' => 'Seleccione la Plantilla empleada para desplegar la lista de Activos que coinciden con una palabra clave, cuando este Archivo de Noticias sea exportado.'
  },
  'keywordCloud' => {
    'lastUpdated' => '1253709680',
    'message' => 'La nube de marcas (<em>tagcloud</em>) con las Palabras Claves de las Noticias en este Archivo de Noticias.'
  },
  'keywordListTemplateId' => {
    'lastUpdated' => '1253709712',
    'message' => 'El GUID de la Plantilla empleada para desplegar los Activos que coinciden con una palabra clave, cuando este Archivo de Noticias sea exportado.'
  },
  'photo width' => {
    'lastUpdated' => '1253709730',
    'message' => 'Anchura de fotos'
  },
  'photo width help' => {
    'lastUpdated' => '1253709787',
    'message' => 'Las fotos desplegadas en el Carrusel YUI deben tener tamaños similares para mostrarse correctamente. La anchura indicada en este campo será utilizada para redimensionar las fotos. Para desactivar esta característica, indique el valor 0.'
  },
  'photoWidth' => {
    'lastUpdated' => '1253709812',
    'message' => 'La anchura a la cual deben ajustarse las fotos incorporadas en las Noticias de este Archivo de Noticias.'
  },
  'rich editor' => {
    'lastUpdated' => '1253709819',
    'message' => 'Editor Extendido'
  },
  'rich editor help' => {
    'lastUpdated' => '1253709840',
    'message' => 'Seleccione el Editor Extendido WYSIWYG que se usará para editar el contenido de las Noticias.'
  },
  'richEditorId' => {
    'lastUpdated' => '1253709863',
    'message' => 'El GUID del Editor Extendido WYSIWYG empleado para editar el contenido de las Noticias.'
  },
  'rssUrl' => {
    'lastUpdated' => '1253709875',
    'message' => 'El URL a la Fuente RSS del Archivo de Noticias.'
  },
  'searchButton' => {
    'lastUpdated' => '1253709909',
    'message' => 'El botón para enviar el formulario. La variable estará vacía si el Archivo de Noticias está siendo exportado a HTML puro.'
  },
  'searchFooter' => {
    'lastUpdated' => '1253709935',
    'message' => 'Código HTML para terminar el formulario de búsqueda. Esta variable estará vacía cuando el Archivo de Noticias sea exportado a HTML.'
  },
  'searchForm' => {
    'lastUpdated' => '1253709962',
    'message' => 'Elemento de formulario para que los usuarios puedan ingresar palabras claves de búsqueda. Esta variable estará vacía cuando el Archivo de Noticias sea exportado a HTML.'
  },
  'searchHeader' => {
    'lastUpdated' => '1253710040',
    'message' => 'Código HTML para comenzar el formulario de búsqueda. Esta variable estará vacía cuando el Archivo de Noticias sea exportado a HTML.'
  },
  'stories per page' => {
    'lastUpdated' => '1253710052',
    'message' => 'Noticias por Página'
  },
  'stories per page help' => {
    'lastUpdated' => '1253710089',
    'message' => 'El número de Noticias que deben desplegarse por página. Si el Activo es exportado hacia HTML, la página generada tendrá 10 Noticias.'
  },
  'story template' => {
    'lastUpdated' => '1253710100',
    'message' => 'Plantilla para Noticia'
  },
  'story template help' => {
    'lastUpdated' => '1253710121',
    'message' => 'Seleccione la Plantilla empleada para desplegar un activo Noticia dentro del Archivo de Noticias.'
  },
  'storyTemplateId' => {
    'lastUpdated' => '1253710152',
    'message' => 'El GUID de la Plantilla empleada para desplegar cada Noticia.'
  },
  'story_loop' => {
    'lastUpdated' => '1253710179',
    'message' => 'Un ciclo que itera sobre las Noticias que fueron enviadas en el día indicado por <strong>epochDate</strong>.'
  },
  'storyarchive asset template variables title' => {
    'lastUpdated' => '1253710195',
    'message' => 'Variables de Plantilla para Archivo de Noticias'
  },
  'template' => {
    'lastUpdated' => '1253710207',
    'message' => 'Plantilla para Archivo de Noticias'
  },
  'template help' => {
    'lastUpdated' => '1253710226',
    'message' => 'Seleccione la Plantilla empleada para desplegar el Archivo de Noticias.'
  },
  'templateId' => {
    'lastUpdated' => '1253710240',
    'message' => 'El GUID de la Plantilla empleada para desplegar el Archivo de Noticias.'
  },
  'title' => {
    'lastUpdated' => '1253710250',
    'message' => 'El Título de una Noticia.'
  },
  'url' => {
    'lastUpdated' => '1253710258',
    'message' => 'El URL para ver una Noticia.'
  },
  'view template' => {
    'lastUpdated' => '1253710278',
    'message' => 'Archivo de Noticias, Plantilla para'
  }
}
;

1;

==> webgui_7.10.23.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_StoryArchive.pm <==
package WebGUI::i18n::Spanish::Asset_StoryArchive;
use utf8;
our $I18N = {
  'add a story' => {
    'lastUpdated' => '1253707884',
    'message' => 'Agregar Noticia'
  },
  'addStoryUrl' => {
    'lastUpdated' => '1253707899',
    'message' => 'El URL para agregar Noticia.'
  },
  'alphabetically' => {
    'lastUpdated' => '1280335550',
    'message' => 'Alfabéticamente'
  },
  'approval workflow' => {
    'lastUpdated' => '1253707911',
    'message' => 'Flujo de Trabajo para Aprobar Noticia'
  },
  'approval workflow help' => {
    'lastUpdated' => '1253707971',
    'message' => 'Seleccione el Flujo de Trabajo que será activado cuando se recibe una Noticia.'
  },
  'approvalWorkflowId' => {
    'lastUpdated' => '1253707992',
    'message' => 'El ID del Flujo de Trabajo a ejecutar cada vez que se envía una Noticia.'
  },
  'archive after' => {
    'lastUpdated' => '1253708028',
    'message' => 'Archivar Noticias después de'
  },
  'archive after help' => {
    'lastUpdated' => '1253708090',
    'message' => 'Una vez transcurrida esta cantidad de tiempo, las Noticias serán archivadas y no aparecerán en la lista de Noticias ni en las Fuentes RSS. Ingrese 0 para deshabilitar el archivado de Noticias.'
  },
  'archiveAfter' => {
    'lastUpdated' => '1253708144',
    'message' => 'Cantidad de tiempo en segundos después de la cual las Noticias deben ser archivadas.'
  },
  'asset title' => {
    'lastUpdated' => '1253708156',
    'message' => 'El Título de este Activo.'
  },
  'asset url' => {
    'lastUpdated' => '1253708183',
    'message' => 'El URL de este Activo.'
  },
  'assetName' => {
    'lastUpdated' => '1253708233',
    'message' => 'Archivo de Noticias'
  },
  'asset_loop' => {
    'lastUpdated' => '1253708276',
    'message' => 'Un ciclo que itera sobre los 50 primeros Activos que coinciden con la palabra clave.'
  },
  'atomUrl' => {
    'lastUpdated' => '1253708336',
    'message' => 'El URL para la Fuente Atom de este Archivo de Noticias.'
  },
  'canPostStories' => {
    'lastUpdated' => '1253708417',
    'message' => 'Un condicional que indica si el usuario puede publicar Noticias.'
  },
  'chronologically' => {
    'lastUpdated' => '1280335555',
    'message' => 'Cronológicamente'
  },
  'creationDate' => {
    'lastUpdated' => '1253708438',
    'message' => 'La fecha en que la Noticia fue creada o enviada al Archivo de Noticias, como una época Unix.'
  },
  'date_loop' => {
    'lastUpdated' => '1253708474',
    'message' => 'Un ciclo que contiene Noticias en el orden de fecha de envío, con ciclos anidados para cada día.'
  },
  'deleteIcon' => {
    'lastUpdated' => '1253708510',
    'message' => 'El ícono para eliminar esta Noticia. Si el usuario no tiene privilegios para eliminar la Noticia o su nivel de interfaz de usuario es muy bajo, la variable estará vacía.'
  },
  'edit story template' => {
    'lastUpdated' => '1253709395',
    'message' => 'Plantilla para Editar Noticia'
  },
  'edit story template help' => {
    'lastUpdated' => '1253709409',
    'message' => 'Seleccione la Plantilla empleada para agregar o editar Noticias.'
  },
  'editIcon' => {
    'lastUpdated' => '1253709441',
    'message' => 'El ícono para editar esta Noticia. Si el usuario no tiene privilegios para editar la Noticia, o su nivel de Interfaz de Usuario es muy bajo, la variable estará vacía.'
  },
  'editStoryTemplateId' => {
    'lastUpdated' => '1253709455',
    'message' => 'El ID de la Plantilla empleada para agregar o editar Noticias.'
  },
  'epochDate' => {
    'lastUpdated' => '1253709486',
    'message' => 'La época de una Noticia es el comienzo del día para el día en que se agregaron Noticias al Archivo de Noticias.'
  },
  'group to post' => {
    'lastUpdated' => '1253709495',
    'message' => 'Grupo que puede Publicar'
  },
  'group to post help' => {
    'lastUpdated' => '1253709509',
    'message' => 'Seleccione el Grupo de usuarios que puede agregar Noticias al Archivo de Noticias.'
  },
  'groupToPost' => {
    'lastUpdated' => '1253709528',
    'message' => 'El GUID del Grupo que puede agregar historias al Archivo de Noticias.'
  },
  'keyword' => {
    'lastUpdated' => '1253709540',
    'message' => 'La palabra clave para esta lista de Activos.'
  },
  'keyword list template' => {
    'lastUpdated' => '1253709560',
    'message' => 'Archivo de Noticias, Plantilla para Lista de Palabras Clave'
  },
  'keyword list template help' => {
    'lastUpdated' => '1253709608',
    'message' => 'Seleccione la Plantilla empleada para desplegar la lista de Activos que coinciden con una palabra clave, cuando este Archivo de Noticias sea exportado.'
  },
  'keywordCloud' => {
    'lastUpdated' => '1253709680',
    'message' => 'La nube de marcas (<em>tagcloud</em>) con las Palabras Claves de las Noticias en este Archivo de Noticias.'
  },
  'keywordListTemplateId' => {
    'lastUpdated' => '1253709712',
    'message' => 'El GUID de la Plantilla empleada para desplegar los Activos que coinciden con una palabra clave, cuando este Archivo de Noticias sea exportado.'
  },
  'photo width' => {
    'lastUpdated' => '1253709730',
    'message' => 'Anchura de fotos'
  },
  'photo width help' => {
    'lastUpdated' => '1253709787',
    'message' => 'Las fotos desplegadas en el Carrusel YUI deben tener tamaños similares para mostrarse correctamente. La anchura indicada en este campo será utilizada para redimensionar las fotos. Para desactivar esta característica, indique el valor 0.'
  },
  'photoWidth' => {
    'lastUpdated' => '1253709812',
    'message' => 'La anchura a la cual deben ajustarse las fotos incorporadas en las Noticias de este Archivo de Noticias.'
  },
  'rich editor' => {
    'lastUpdated' => '1253709819',
    'message' => 'Editor Extendido'
  },
  'rich editor help' => {
    'lastUpdated' => '1253709840',
    'message' => 'Seleccione el Editor Extendido WYSIWYG que se usará para editar el contenido de las Noticias.'
  },
  'richEditorId' => {
    'lastUpdated' => '1253709863',
    'message' => 'El GUID del Editor Extendido WYSIWYG empleado para editar el contenido de las Noticias.'
  },
  'rssUrl' => {
    'lastUpdated' => '1253709875',
    'message' => 'El URL a la Fuente RSS del Archivo de Noticias.'
  },
  'searchButton' => {
    'lastUpdated' => '1253709909',
    'message' => 'El botón para enviar el formulario. La variable estará vacía si el Archivo de Noticias está siendo exportado a HTML puro.'
  },
  'searchFooter' => {
    'lastUpdated' => '1253709935',
    'message' => 'Código HTML para terminar el formulario de búsqueda. Esta variable estará vacía cuando el Archivo de Noticias sea exportado a HTML.'
  },
  'searchForm' => {
    'lastUpdated' => '1253709962',
    'message' => 'Elemento de formulario para que los usuarios puedan ingresar palabras claves de búsqueda. Esta variable estará vacía cuando el Archivo de Noticias sea exportado a HTML.'
  },
  'searchHeader' => {
    'lastUpdated' => '1253710040',
    'message' => 'Código HTML para comenzar el formulario de búsqueda. Esta variable estará vacía cuando el Archivo de Noticias sea exportado a HTML.'
  },
  'sortAlphabeticallyChronologically' => {
    'lastUpdated' => '1280335565',
    'message' => 'Ordenar'
  },
  'sortAlphabeticallyChronologically description' => {
    'lastUpdated' => '1280335589',
    'message' => 'Indica si los mensajes aparecen en orden de publicación o según el título.'
  },
  'stories per page' => {
    'lastUpdated' => '1253710052',
    'message' => 'Noticias por Página'
  },
  'stories per page help' => {
    'lastUpdated' => '1253710089',
    'message' => 'El número de Noticias que deben desplegarse por página. Si el Activo es exportado hacia HTML, la página generada tendrá 10 Noticias.'
  },
  'story template' => {
    'lastUpdated' => '1253710100',
    'message' => 'Plantilla para Noticia'
  },
  'story template help' => {
    'lastUpdated' => '1253710121',
    'message' => 'Seleccione la Plantilla empleada para desplegar un activo Noticia dentro del Archivo de Noticias.'
  },
  'storyTemplateId' => {
    'lastUpdated' => '1253710152',
    'message' => 'El GUID de la Plantilla empleada para desplegar cada Noticia.'
  },
  'story_loop' => {
    'lastUpdated' => '1253710179',
    'message' => 'Un ciclo que itera sobre las Noticias que fueron enviadas en el día indicado por <strong>epochDate</strong>.'
  },
  'storyarchive asset template variables title' => {
    'lastUpdated' => '1253710195',
    'message' => 'Variables de Plantilla para Archivo de Noticias'
  },
  'template' => {
    'lastUpdated' => '1253710207',
    'message' => 'Plantilla para Archivo de Noticias'
  },
  'template help' => {
    'lastUpdated' => '1253710226',
    'message' => 'Seleccione la Plantilla empleada para desplegar el Archivo de Noticias.'
  },
  'templateId' => {
    'lastUpdated' => '1253710240',
    'message' => 'El GUID de la Plantilla empleada para desplegar el Archivo de Noticias.'
  },
  'title' => {
    'lastUpdated' => '1253710250',
    'message' => 'El Título de una Noticia.'
  },
  'url' => {
    'lastUpdated' => '1253710258',
    'message' => 'El URL para ver una Noticia.'
  },
  'view template' => {
    'lastUpdated' => '1253710278',
    'message' => 'Archivo de Noticias, Plantilla para'
  }
}
;

1;
